/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Romain Rouvoy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.ccm.plugins.transaction.deployment; 



/**
 * Transaction implementation for the
 * ::Deployment::listener::CCMHomeListener interface.
 *
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 *
 * @version 0.3
 */ 
public class CCMHomeListenerTransaction
extends org.objectweb.ccm.Deployment.listener.CCMHomeListenerBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    /**
     * List of resources non committed
     */
    protected org.objectweb.ccm.util.Vector resources_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================
    /**
     * Constructor with parameter
     *
     * @param source the event source
     */
    public
    CCMHomeListenerTransaction()
    {
        resources_ = new org.objectweb.ccm.util.Vector ();
    }

		// ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
		/**
     * Provide a new instance of the class
     *
     * @return new instance
     */
    protected org.objectweb.ccm.Deployment.listener.CCMHomeListener
		_new()
    {
				return new CCMHomeListenerTransaction();
    }

    /**
		 * Provide the reference of the resource corresponding to the current transaction
		 *
		 * @return the current resource
		 */
    protected CCMHomeResource
    get_resource()
    {
        try
        {
            org.omg.CORBA.Object obj = org.objectweb.ccm.CORBA.TheORB.getORB().resolve_initial_references("TransactionCurrent");            
            org.omg.CosTransactions.Current current = org.omg.CosTransactions.CurrentHelper.narrow( obj );            
            org.omg.CosTransactions.Coordinator coordinator = current.get_control().get_coordinator();
            CCMHomeResource resource = null;

						for ( int i=0 ; i<resources_.size() ; i++ )
            {
                resource = (CCMHomeResource) resources_.elementAt( i );
                
                if (coordinator.is_same_transaction(resource.coordinator()))
                    return resource;
            }
						return new CCMHomeResourceImpl(this,
																					 source_, 
																					 coordinator, 
																					 TheTransactionManager.get_instance().getCurrent());
        } catch ( org.omg.CORBA.ORBPackage.InvalidName ex ) {
            throw new org.omg.CORBA.TRANSACTION_REQUIRED();
        } catch ( org.omg.CosTransactions.Unavailable ex ) {
            throw new org.omg.CORBA.TRANSACTION_REQUIRED();
        } catch ( java.lang.Exception ex ) {
            ex.printStackTrace();
            throw new org.omg.CORBA.TRANSACTION_REQUIRED();
        }
    }   

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

		public void
		add_resource(CCMHomeResource resource)
		{
				resources_.addElement( resource );
		}

		public void
		remove_resource(CCMHomeResource resource)
		{
				resources_.removeElement( resource );
		}

    // ==================================================================
    //
    // Methods for the ::Deployment::listener::CCMHomeEvents interface.
    //
    // ==================================================================
    //
    //  IDL:omg.org/Deployment/listener/CCMHomeEvents/on_create:1.0
    //
    /**
     * Event sent after the create function is called on CCMHome object
     *
     * @param ref the object created
     */ 
    public void
    on_create (org.omg.Components.CCMObject ref)
    {
        delegate_.on_create (ref);
        get_resource().on_create(ref); 
    }
    
    //
    //  IDL:omg.org/Deployment/listener/CCMHomeEvents/on_add:1.0
    //
    /**
     * Event sent after the add function is called on CCMHome object
     *
     * @param ref the object added
     */ 
    public void
    on_add (org.omg.Components.CCMObject ref )
    {
        delegate_.on_add (ref);
    }
    
    //
    //  IDL:omg.org/Deployment/listener/CCMHomeEvents/on_remove:1.0
    //
    /**
     * Event sent before the remove function is called on CCMHome object
     *
     * @param ref the object removed
     */ 
    public void
    on_remove (org.omg.Components.CCMObject ref)
    {
        delegate_.on_remove (ref);
    }
    
    //
    //  IDL:omg.org/Deployment/listener/CCMHomeEvents/on_destroy:1.0
    //
    /**
     * Event sent before the destruction of the related CCMHome object 
     *
     */ 
    public void
    on_destroy ()
    {
        delegate_.on_destroy ();
    }
}



