/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.ast.lib;

/** To access AST DeclarationKind. */
import org.objectweb.corba.ast.api.DeclarationKind;

/** To access AST Declaration. */
import org.objectweb.corba.ast.api.Declaration;

/** To use AST StorageTypeDecl */
import org.objectweb.corba.ast.api.StorageTypeDecl;

/** To use AST StorageHomeDecl */
import org.objectweb.corba.ast.api.StorageHomeDecl;

/**
 * StorageTypeStoreDirectiveDeclImpl is a wrapper class for
 * PSDL storagetype state member declarations.
 *
 *
 * Inherits from:
 *
 * - DeclarationImpl as they are IDL declarations,
 *
 * - StorageTypeStateMemberDecl: OMG IDL for PSDL storagetype store
 *   directive declarations.
 *
 *
 * Provides:
 *
 * - The 'Readonly' property,
 *   i.e. the setReadonly and isReadonly operations.
 *
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class StorageTypeStoreDirectiveDeclImpl
     extends DeclarationImpl
  implements org.objectweb.corba.ast.api.StorageTypeStoreDirectiveDecl
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The state member's name. */
    private String state_member_;

    /** Is the storagetype a reference? */
    private boolean ref_;

    /** The state member's type. */
    private StorageTypeDeclImpl storage_type_;

    /** The storage home where the state member must be stored. */
    private StorageHomeDeclImpl storage_home_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The constructor with the parent scope.
     *
     * @param rep The repository of the declaration.
     * @param parent The parent scope of the value member declaration.
     **/
    protected
    StorageTypeStoreDirectiveDeclImpl(Repository rep,
                                      ScopeImpl parent)
    {
        // Call the DeclarationWithTypeRefImpl constructor.
        super(rep, parent);

        // Init internal state.
        state_member_ = null;
        ref_ = false;
        storage_type_ = null;
        storage_home_ = null;;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods for DeclarationImpl.
    //
    // ==================================================================

    /**
     * Obtain its CORBA 3.0 Contained reference.
     *
     * @return The Contained object associated with the value
     *         member declaration.
     */
    protected org.omg.CORBA.Contained
    getContained()
    {
        // TODO
        return null;
    }

    // ==================================================================
    //
    // Internal methods for DeclarationWithTypeRefImpl.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL org.objectweb.corba.ast.api.WithDependencies
    //
    // ==================================================================

    /**
     * Obtain the declaration external dependencies.
     *
     * Note: for scopes, contained objects are not considered
     *       as dependencies.
     *
     * @return The list of dependencies as an array of Declaration.
     */
    public Declaration[]
    getDependencies()
    {
        // TODO
        return null;
    }

    // ==================================================================
    //
    // Methods for OMG IDL org.objectweb.corba.ast.api.Declaration
    //
    // ==================================================================

    /**
     * Obtain its DeclarationKind.
     *
     * @return The DeclarationKind of the object.
     */
    public long
    getDeclKind()
    {
        return DeclarationKind.dk_storage_type_store_directive;
    }

    /**
     * Create the value member declaration into the IFR.
     */
    public void
    create()
    {
        // TODO
        super.create();
    }

    // ==================================================================
    //
    // Methods for OMG IDL org.objectweb.corba.ast.api.StorageTypeStoreDirectiveDecl
    //
    // ==================================================================

    /**
     * Set the state member.
     *
     * @param name The state member's name.
     */
    public void
    setStateMember(String name)
    {
        state_member_ = name;
    }

    /**
     * Get the state member
     *
     * @return The state member.
     */
    public String
    getStateMember()
    {
        return state_member_;
    }

    /**
     * Set as a storagetype's reference.
     *
     * @param b True if it is a storagetype's reference, or false otherwise.
     */
    public void
    setRef(boolean b)
    {
        ref_ = b;
    }

    /**
     * Is it a storagetype's reference?
     *
     * @return True if it is a storagetype's reference, else false.
     */
    public boolean
    isRef()
    {
        return ref_;
    }


    /*  THIS METHOD MUST BE REVISED */

    /**
     * Set the state member's type.
     *
     * @param st The state member's type.
     */
    public void
    setStorageType(StorageTypeDecl st)
    {
    }

    /*  THIS METHOD MUST BE REVISED */

    /**
     * Get the state member's type
     *
     * @return The state member's type.
     */
    public StorageTypeDecl
    getStorageType()
    {
        return null;
    }

    /**
     * Set the storage home.
     *
     * @param sh The storage home where the state member must be stored.
     */
    public void
    setStorageHome(StorageHomeDecl sh)
    {
        storage_home_ = (StorageHomeDeclImpl)sh;
    }

    /**
     * Get the storage home.
     *
     * @return The storage home where the state member must be stored.
     */
    public StorageHomeDecl
    getStorageHome()
    {
        return storage_home_;
    }
}
